==> jc-1.4.0.tar.gz: soot/baf/internal/BDup2Inst.h <==
// public class soot.baf.internal.BDup2Inst

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class d4b4063f9cbfdfdb soot_baf_internal_BDup2Inst
// @dep_class b9914bc9f2a73744 soot_baf_internal_BDupInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_BDupInst

#include "soot/baf/internal/BDupInst.h"

#ifndef _JC_soot_baf_internal_BDup2Inst_H_
#define _JC_soot_baf_internal_BDup2Inst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_Type$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_baf_internal_BDup2Inst$sub_refs	_jc_soot_baf_internal_BDup2Inst$sub_refs;
typedef struct _jc_soot_baf_internal_BDup2Inst$sub_nonrefs	_jc_soot_baf_internal_BDup2Inst$sub_nonrefs;
typedef struct _jc_soot_baf_internal_BDup2Inst$refs	_jc_soot_baf_internal_BDup2Inst$refs;
typedef struct _jc_soot_baf_internal_BDup2Inst$nonrefs	_jc_soot_baf_internal_BDup2Inst$nonrefs;
typedef struct _jc_soot_baf_internal_BDup2Inst$object	_jc_soot_baf_internal_BDup2Inst$object;

typedef const struct _jc_soot_baf_internal_BDup2Inst$vmethods	_jc_soot_baf_internal_BDup2Inst$vmethods;
typedef const struct _jc_soot_baf_internal_BDup2Inst$vtable	_jc_soot_baf_internal_BDup2Inst$vtable;
typedef const struct _jc_soot_baf_internal_BDup2Inst$vtype	_jc_soot_baf_internal_BDup2Inst$vtype;

// Constructors
extern void _jc_soot_baf_internal_BDup2Inst$method$_init$91936ea0628022dd(_jc_env *, struct _jc_soot_baf_internal_BDup2Inst$object *, struct _jc_soot_Type$object *, struct _jc_soot_Type$object *);

// Virtual methods
extern void _jc_soot_baf_internal_BDup2Inst$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_baf_internal_BDup2Inst$object *, struct _jc_object *);
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_BDup2Inst$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_baf_internal_BDup2Inst$object *);
extern struct _jc_soot_Type$object *_jc_soot_baf_internal_BDup2Inst$method$getOp1Type$5b5a95267a257907(_jc_env *, struct _jc_soot_baf_internal_BDup2Inst$object *);
extern struct _jc_soot_Type$object *_jc_soot_baf_internal_BDup2Inst$method$getOp2Type$99265d49ca3d404a(_jc_env *, struct _jc_soot_baf_internal_BDup2Inst$object *);
extern struct _jc_object *_jc_soot_baf_internal_BDup2Inst$method$getOpTypes$b3c24cdbe2ebfd24(_jc_env *, struct _jc_soot_baf_internal_BDup2Inst$object *);
extern struct _jc_object *_jc_soot_baf_internal_BDup2Inst$method$getUnderTypes$0a8a26956d640ea7(_jc_env *, struct _jc_soot_baf_internal_BDup2Inst$object *);
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_BDup2Inst$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_baf_internal_BDup2Inst$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_BDup2Inst$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_baf_internal_BDup2Inst$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_baf_internal_BDup2Inst$method_info$getOp1Type$5b5a95267a257907;
extern _jc_method _jc_soot_baf_internal_BDup2Inst$method_info$getOp2Type$99265d49ca3d404a;
extern _jc_method _jc_soot_baf_internal_BDup2Inst$method_info$getOpTypes$b3c24cdbe2ebfd24;
extern _jc_method _jc_soot_baf_internal_BDup2Inst$method_info$getUnderTypes$0a8a26956d640ea7;
extern _jc_method _jc_soot_baf_internal_BDup2Inst$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_baf_internal_BDup2Inst$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_baf_internal_BDup2Inst$object *, struct _jc_object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_baf_internal_BDup2Inst$object *);
	struct _jc_soot_Type$object	*(*getOp1Type$5b5a95267a257907)(_jc_env *, struct _jc_soot_baf_internal_BDup2Inst$object *);
	struct _jc_soot_Type$object	*(*getOp2Type$99265d49ca3d404a)(_jc_env *, struct _jc_soot_baf_internal_BDup2Inst$object *);
	struct _jc_object	*(*getOpTypes$b3c24cdbe2ebfd24)(_jc_env *, struct _jc_soot_baf_internal_BDup2Inst$object *);
	struct _jc_object	*(*getUnderTypes$0a8a26956d640ea7)(_jc_env *, struct _jc_soot_baf_internal_BDup2Inst$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_baf_internal_BDup2Inst$object *);
};

// Vtable
struct _jc_soot_baf_internal_BDup2Inst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_internal_BDupInst$vmethods	soot_baf_internal_BDupInst;
	_jc_soot_baf_internal_BDup2Inst$vmethods	soot_baf_internal_BDup2Inst;
};

// Vtype
struct _jc_soot_baf_internal_BDup2Inst$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_BDup2Inst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_BDup2Inst$sub_refs {
	struct _jc_soot_Type$object	*mOp1Type;
	struct _jc_soot_Type$object	*mOp2Type;
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_BDup2Inst$refs {
    _jc_soot_baf_internal_BDup2Inst$sub_refs	soot_baf_internal_BDup2Inst;
    _jc_soot_baf_internal_BDupInst$sub_refs	soot_baf_internal_BDupInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_BDup2Inst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_BDup2Inst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_internal_BDupInst$sub_nonrefs	soot_baf_internal_BDupInst;
    _jc_soot_baf_internal_BDup2Inst$sub_nonrefs	soot_baf_internal_BDup2Inst;
};

// Object instance structure
struct _jc_soot_baf_internal_BDup2Inst$object {
	_jc_soot_baf_internal_BDup2Inst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_BDup2Inst$vtype	*vtype;
	_jc_soot_baf_internal_BDup2Inst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_BDup2Inst$vtype _jc_soot_baf_internal_BDup2Inst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_BDup2Inst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_BDup2Inst$class_object;

#endif	/* _JC_soot_baf_internal_BDup2Inst_H_ */

==> jc-1.4.6.tar.gz: soot/baf/internal/BDup2Inst.h <==
// public class soot.baf.internal.BDup2Inst

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class d4b4063f9cbfdfdb soot_baf_internal_BDup2Inst
// @dep_class b9914bc9f2a73744 soot_baf_internal_BDupInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_BDupInst

#include "soot/baf/internal/BDupInst.h"

#ifndef _JC_soot_baf_internal_BDup2Inst_H_
#define _JC_soot_baf_internal_BDup2Inst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_Type$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_baf_internal_BDup2Inst$sub_refs	_jc_soot_baf_internal_BDup2Inst$sub_refs;
typedef struct _jc_soot_baf_internal_BDup2Inst$sub_nonrefs	_jc_soot_baf_internal_BDup2Inst$sub_nonrefs;
typedef struct _jc_soot_baf_internal_BDup2Inst$refs	_jc_soot_baf_internal_BDup2Inst$refs;
typedef struct _jc_soot_baf_internal_BDup2Inst$nonrefs	_jc_soot_baf_internal_BDup2Inst$nonrefs;
typedef struct _jc_soot_baf_internal_BDup2Inst$object	_jc_soot_baf_internal_BDup2Inst$object;

typedef const struct _jc_soot_baf_internal_BDup2Inst$vmethods	_jc_soot_baf_internal_BDup2Inst$vmethods;
typedef const struct _jc_soot_baf_internal_BDup2Inst$vtable	_jc_soot_baf_internal_BDup2Inst$vtable;
typedef const struct _jc_soot_baf_internal_BDup2Inst$vtype	_jc_soot_baf_internal_BDup2Inst$vtype;

// Constructors
extern void _jc_soot_baf_internal_BDup2Inst$method$_init$91936ea0628022dd(_jc_env *, struct _jc_soot_baf_internal_BDup2Inst$object *, struct _jc_soot_Type$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_baf_internal_BDup2Inst$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_baf_internal_BDup2Inst$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_BDup2Inst$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_baf_internal_BDup2Inst$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_Type$object *_jc_soot_baf_internal_BDup2Inst$method$getOp1Type$5b5a95267a257907(_jc_env *, struct _jc_soot_baf_internal_BDup2Inst$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_Type$object *_jc_soot_baf_internal_BDup2Inst$method$getOp2Type$99265d49ca3d404a(_jc_env *, struct _jc_soot_baf_internal_BDup2Inst$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_baf_internal_BDup2Inst$method$getOpTypes$b3c24cdbe2ebfd24(_jc_env *, struct _jc_soot_baf_internal_BDup2Inst$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_baf_internal_BDup2Inst$method$getUnderTypes$0a8a26956d640ea7(_jc_env *, struct _jc_soot_baf_internal_BDup2Inst$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_BDup2Inst$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_baf_internal_BDup2Inst$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_BDup2Inst$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_baf_internal_BDup2Inst$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_baf_internal_BDup2Inst$method_info$getOp1Type$5b5a95267a257907;
extern _jc_method _jc_soot_baf_internal_BDup2Inst$method_info$getOp2Type$99265d49ca3d404a;
extern _jc_method _jc_soot_baf_internal_BDup2Inst$method_info$getOpTypes$b3c24cdbe2ebfd24;
extern _jc_method _jc_soot_baf_internal_BDup2Inst$method_info$getUnderTypes$0a8a26956d640ea7;
extern _jc_method _jc_soot_baf_internal_BDup2Inst$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_baf_internal_BDup2Inst$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_baf_internal_BDup2Inst$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_baf_internal_BDup2Inst$object *) _JC_JCNI_ATTR;
	struct _jc_soot_Type$object	*(*getOp1Type$5b5a95267a257907)(_jc_env *, struct _jc_soot_baf_internal_BDup2Inst$object *) _JC_JCNI_ATTR;
	struct _jc_soot_Type$object	*(*getOp2Type$99265d49ca3d404a)(_jc_env *, struct _jc_soot_baf_internal_BDup2Inst$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getOpTypes$b3c24cdbe2ebfd24)(_jc_env *, struct _jc_soot_baf_internal_BDup2Inst$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getUnderTypes$0a8a26956d640ea7)(_jc_env *, struct _jc_soot_baf_internal_BDup2Inst$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_baf_internal_BDup2Inst$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_baf_internal_BDup2Inst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_internal_BDupInst$vmethods	soot_baf_internal_BDupInst;
	_jc_soot_baf_internal_BDup2Inst$vmethods	soot_baf_internal_BDup2Inst;
};

// Vtype
struct _jc_soot_baf_internal_BDup2Inst$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_BDup2Inst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_BDup2Inst$sub_refs {
	struct _jc_soot_Type$object	*mOp1Type;
	struct _jc_soot_Type$object	*mOp2Type;
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_BDup2Inst$refs {
    _jc_soot_baf_internal_BDup2Inst$sub_refs	soot_baf_internal_BDup2Inst;
    _jc_soot_baf_internal_BDupInst$sub_refs	soot_baf_internal_BDupInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_BDup2Inst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_BDup2Inst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_internal_BDupInst$sub_nonrefs	soot_baf_internal_BDupInst;
    _jc_soot_baf_internal_BDup2Inst$sub_nonrefs	soot_baf_internal_BDup2Inst;
};

// Object instance structure
struct _jc_soot_baf_internal_BDup2Inst$object {
	_jc_soot_baf_internal_BDup2Inst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_BDup2Inst$vtype	*vtype;
	_jc_soot_baf_internal_BDup2Inst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_BDup2Inst$vtype _jc_soot_baf_internal_BDup2Inst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_BDup2Inst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_BDup2Inst$class_object;

#endif	/* _JC_soot_baf_internal_BDup2Inst_H_ */
